
*     ***************************************************************** * 
*     ***************************************************************** * 
*       File-Name:      analysis2.do                                    * 
*       Date:           March 25, 2016                                  * 
*       Author:         Gschwend, Zittel                                * 
*       Purpose:      	Performs analysis  (logit)                      * 
* 	    Input File:     data.dta                                        * 
*       Data Output:                                                    *              
*     ****************************************************************  * 
*     ****************************************************************  * 


* TG added minor edits (8 July 2016)


use data, clear
set more off

sum personal_id
assert r(N)== 2953  & r(min)==1 & r(max)==1903 & r(sum)==2473222

sum porcassignment1
assert r(N)== 2358  & r(min)==0 & r(max)==1 & r(sum)==374



sum newdv porcassignment* locpol locbio  localexp margin*  nomlist small legterm*  woman personal_id




logit porcassignment1 locpol locbio   margin3 nomlist small legterm woman
logit porcassignment1 locpol locbio   margin3 nomlist small legterm woman, cluster(personal_id)
logit porcassignment1 locpol locbio    nomlist small legterm woman, cluster(personal_id)


**************
** Table 4  **
**************

logit porcassignment1 locpol locbio   margin3 nomlist small legterm woman, cluster(personal_id)
estadd scalar LL = e(ll)
estadd scalar Observations = e(N)
estadd scalar MPs = e(N_clust)
estat classification
estadd scalar PCP = r(P_corr)
eststo est0

#delimit ;
esttab est0 using logit_ini_mem.rtf, replace b(%9.2f) se(%9.2f)  rtf  nolabel star(* 0.10 ** 0.05 *** 0.01)
title (Who ends-up in a pork committee? - Initial assigment, members only)
varlabels(_cons "Constant"  locbio "Local Biography" locpol "Local Politics"
          nomlist "Mode of Election (1 = Nominal)" localexp "Local Party" reassign "Reassignment (1 = yes)" 
          small "Small Party (= 1)" legterm "Legislative terms" margin3 "Margin" woman "Female (= 1)")
 stats(LL Observations MPs PCP, labels("Log-Lik." "Observations" "No. of different MPs" "Percent Correctly Predicted (PCP)") fmt(%9.0f))
nonumbers varwidth(35) modelwidth(20) mtitles("District Committee (= 1)") 
order(nomlist locbio locpol legterm small)
;
#delimit cr

gen esample = (e(sample)==1)



*varlabels(`e(labels)', blist(Total "{hline @width}{break}"))  
 
* Some more ideas:
* nonotes addnote("N = `e(N)'; clustered standard errors in parentheses; * p < 0.1, ** p < 0.05, *** p < 0.01") 
* title({\b Table 1.} {\i This is the 1{\super st} table})

* check for more: http://repec.org/bocode/e/estout/hlp_estout.html





*************
** Table 1 **
*************

fre distbirth if  esample==1
fre distschool if  esample==1
fre distresid if  esample==1

fre locpol locbio if  esample==1
fre local_assembly mayor if  esample==1
 
 
***********************************
** further reported descriptives  *
***********************************



fre porcassignment1 nomlist small  legterm woman newdv if  esample==1
sum legterm if  esample==1, detail



*************
** Table 3 **
*************
tabulate nomlist porcassignment1  if  esample==1, all cell
tabulate locpol porcassignment1  if  esample==1, all cell
tabulate locbio porcassignment1  if  esample==1, all cell

*********************
** Robustness test **
*********************



* Stratman/Baur use only large party MPs, we argue, however, that the mechanism should be the same 
* no matter small or large party MP

logit porcassignment1 locpol locbio   margin3 nomlist  legterm woman if initial==1 & initialp==1 & small==0, cluster(personal_id)
logit porcassignment1 locpol locbio   margin3 nomlist  legterm woman if initial==1 & initialp==1 & small==1, cluster(personal_id)
* Results for large party MPs are the same as in the baseline model. Moreover, the results are largely the same for large and small party MPs !!!
*  local pol does matter , nomlist does not matter. Margin does not matter for small .

* Results are robust, 1% better fit!!
logit porcassignment1 locpol locbio   margin3 nomlist small legterm woman i.election_year, cluster(personal_id)
estat classification



* Robust, if one election year is excluded at a time? Yup, remarkably stable except margin (only sig in 2 out of 5 cases)
logit porcassignment1 locpol locbio   margin3 nomlist small legterm woman if  y1!=1, cluster(personal_id)/* drop 1983  */
estat classification
logit porcassignment1 locpol locbio   margin3 nomlist small legterm woman if  y2!=1, cluster(personal_id)/* drop 1987  */
estat classification
logit porcassignment1 locpol locbio   margin3 nomlist small legterm woman if  y3!=1, cluster(personal_id)/* drop 1998  */
estat classification
logit porcassignment1 locpol locbio   margin3 nomlist small legterm woman if  y4!=1, cluster(personal_id)/* drop 2005  */
estat classification
logit porcassignment1 locpol locbio   margin3 nomlist small legterm woman if  y5!=1, cluster(personal_id)/* drop 2009  */
estat classification





keep newdv porcassignment* locpol locbio   margin3 nomlist small legterm woman y* election_year personal_id initial* comtab2
keep if e(sample)
compress
save analysis1, replace






** MNL Model

mlogit newdv locpol locbio   margin3 nomlist small legterm woman, cluster(personal_id) 
predict prob*
egen pred_max = rowmax(prob*)
gen pred_choice = .
forv i=1/3 {
 replace pred_choice = `i' if (pred_max == prob`i')
}
tab pred_choice newdv
drop pred_choice prob* pred_max

estadd scalar LL = e(ll)
estadd scalar Observations = e(N)
estadd scalar MPs = e(N_clust)
eststo est1

#delimit ;
esttab est1 using mnl_all.rtf, replace b(%9.2f) se(%9.2f)  rtf  nolabel star(* 0.10 ** 0.05 *** 0.01)
title (Who ends-up in which committee?)
varlabels(_cons "Constant"  locbio "Local Biography" locpol "Local Politics"
          nomlist "Mode of Election (1 = Nominal)" localexp "Local Party" reassign "Reassignment (1 = yes)" 
          small "Small Party (= 1)" legterm "Legislative terms" margin3 "Margin" woman "Female (= 1)")
 stats(LL Observations MPs , labels("Log-Lik." "Observations" "No. of different MPs") fmt(%9.0f))
nonumbers varwidth(35) modelwidth(20)  collabels(" ")
order(nomlist locbio locpol legterm small) unstack
;
#delimit cr





mlogit newdv locpol locbio   margin3 nomlist small legterm woman i.election_year, cluster(personal_id) 
predict prob*
egen pred_max = rowmax(prob*)
gen pred_choice = .
forv i=1/3 {
 replace pred_choice = `i' if (pred_max == prob`i')
}
tab pred_choice newdv
drop pred_choice prob* pred_max

estadd scalar LL = e(ll)
estadd scalar Observations = e(N)
estadd scalar MPs = e(N_clust)
eststo est1

#delimit ;
esttab est1 using mnl_ini_fix.rtf, replace b(%9.2f) se(%9.2f)  rtf  nolabel star(* 0.10 ** 0.05 *** 0.01)
title (Who ends-up in which committee?)
varlabels(_cons "Constant"  locbio "Local Biography" locpol "Local Politics"
          nomlist "Mode of Election (1 = Nominal)" localexp "Local Party" reassign "Reassignment (1 = yes)" 
          small "Small Party (= 1)" legterm "Legislative terms" margin3 "Margin" woman "Female (= 1)")
 stats(LL Observations MPs , labels("Log-Lik." "Observations" "No. of different MPs") fmt(%9.0f))
nonumbers varwidth(35) modelwidth(20)  collabels(" ")
order(nomlist locbio locpol legterm small) unstack
;
#delimit cr





keep newdv porcassignment* locpol locbio   margin3 nomlist small legterm woman y* election_year personal_id initial* comtab2
keep if e(sample)
compress
save analysis1, replace
exit


exit







** hirachical model set-up: Qualitatively the same results

xtset personal_id
xtlogit porcassignment1 locpol locbio   margin3 nomlist small legterm1 woman i.election_year if initial==1 & initialp==1, re 
quadchk, nooutput
*Result: quadrature is not reliably approximating the likelihood!

xtlogit porcassignment locpol locbio   margin3 nomlist small legterm woman i.election_year if initial==1 & initialp==1, re intpoints(30)
quadchk, nooutput //check wether relative differences is around 0.01. 
* Result: Everything fine
* Refitting model intpoints() = 20
* Refitting model intpoints() = 30

* Robust, if one election year is excluded at a time? 
* I comment this out because it takes a while to run.
/*
xtlogit porcassignment localpol localbio  localexp nomlist small if y1!=1, re intpoints(16)
xtlogit porcassignment localpol localbio  localexp nomlist small if y2!=1, re intpoints(16)
xtlogit porcassignment localpol localbio  localexp nomlist small if y3!=1, re intpoints(16)
xtlogit porcassignment localpol localbio  localexp nomlist small if y4!=1, re intpoints(16)
xtlogit porcassignment localpol localbio  localexp nomlist small if y5!=1, re intpoints(16)
*/


xtset persid
xtlogit porcassignment locpol locbio   margin3 nomlist small legterm woman i.election_year if initial==1 & initialp==1, re 
quadchk, nooutput

xtlogit porcassignment locpol locbio   margin3 nomlist small legterm woman i.election_year if initial==1 & initialp==1, re intpoints(30)
quadchk, nooutput //check wether relative differences is around 0.01. 
* Result: lnsig2u is not reliably estimated
* Refitting model intpoints() = 20
* Refitting model intpoints() = 30



bysort small: xtlogit porcassignment locpol locbio   margin3 nomlist  legterm woman, re intpoints(30)
* same here: Results stay the same even if we subsample only large or only small party MPs

keep newdv porcassignment locpol locbio   margin3 nomlist small legterm woman y* election_year personal_id 
*keep if e(sample)
compress
save analysis1, replace
exit




