
*     ***************************************************************** * 
*     ***************************************************************** * 
*       File-Name:      data.do                                         * 
*       Date:           March 25, 2016                                  * 
*       Author:         Gschwend, Zittel                                * 
*       Purpose:      	Imports the data and performs basic             *
*                       recoding of variables                           * 
* 	    Input File:     All_Data_24032016.dta  &   ausschuss_wp17.dta   * 
*       Data Output:    data83-09ext.dta                                *              
*     ****************************************************************  * 
*     ****************************************************************  * 



version 14.1
set more off

*import delimited All_Data_29032016.csv, clear 

// import excel  All_Data_31032016.xlsx, firstrow clear
// ren id id0
// ren A Col1
// ren ID id
// save "All_Data_31032016.dta", replace



// * This is done prior to the import
/* import excel ausschuss_wp17_v3, firstrow clear
 drop full_name
 destring id0, replace
 sort id0
 compress
 save ausschuss_wp17new, replace
*/

use "All_Data_31032016.dta", clear
destring id0, replace
sort id0
drop sex
merge id0 using gender // I handcoded the missings in the gender variable
tab _merge
drop _merge
sort id0

merge id0 using ausschuss_wp17new
tab _merge
keep if _merge==3
drop _merge

* correct data

* id0 = 377 & 373 Gisbert Paar
* id0 = 519 & 520 Klaus Reichenbach
* id0 = 1135 & 1136 Irmgard Adam-Schwaetzer

replace name = "Guenther" if id0==1748
replace name = "Helling" if id0==1854

replace name = "Francke" if id0==1856
replace fname = "Klaus" if id0==1856

drop if id0 == .  /* id0=="1181" wahrscheinlich falsch eingelesen */

gen problem = .
replace problem = 1 if id0==1748
replace problem = 1 if id0==1854
replace problem = 1 if id0==1856
replace problem = 1 if id0==1181
order Col1 - name problem fname


* generate id variable for MP 
egen personal_id1 = group(Col1)
egen personal_id2 = group(id)
egen personal_id3 = group(id0)
sum personal_id*
ren personal_id3 personal_id
drop personal_id1 personal_id2
order personal_id
drop X_1-ID17 

*destring sex, replace

/*
* fix date in LP16
* 30.11.05 into 30/11/2005

forvalues i = 1(1)23 {
capture gen xseit16_`i'_a = regexs(2)+"/"+regexs(1)+"/20"+regexs(3) if regexm(seit16_`i'_a, "([0-9]+)[.]([0-9]+)[.]([0-9][0-9])")
capture gen xseit16_`i'_b = regexs(2)+"/"+regexs(1)+"/20"+regexs(3) if regexm(seit16_`i'_b, "([0-9]+)[.]([0-9]+)[.]([0-9][0-9])")
capture gen xseit16_`i'_c = regexs(2)+"/"+regexs(1)+"/20"+regexs(3) if regexm(seit16_`i'_c, "([0-9]+)[.]([0-9]+)[.]([0-9][0-9])")

capture gen xbis16_`i'_a = regexs(2)+"/"+regexs(1)+"/20"+regexs(3) if regexm(bis16_`i'_a, "([0-9]+)[.]([0-9]+)[.]([0-9][0-9])")
capture gen xbis16_`i'_b = regexs(2)+"/"+regexs(1)+"/20"+regexs(3) if regexm(bis16_`i'_b, "([0-9]+)[.]([0-9]+)[.]([0-9][0-9])")
capture gen xbis16_`i'_c = regexs(2)+"/"+regexs(1)+"/20"+regexs(3) if regexm(bis16_`i'_c, "([0-9]+)[.]([0-9]+)[.]([0-9][0-9])")

capture drop seit16_`i'_a
capture drop seit16_`i'_b
capture drop seit16_`i'_c

capture drop bis16_`i'_a
capture drop bis16_`i'_b
capture drop bis16_`i'_c

capture ren xseit16_`i'_a seit16_`i'_a
capture ren xseit16_`i'_b seit16_`i'_b
capture ren xseit16_`i'_c seit16_`i'_c

capture ren xbis16_`i'_a bis16_`i'_a
capture ren xbis16_`i'_b bis16_`i'_b
capture ren xbis16_`i'_c bis16_`i'_c
}

*/

**************************
* extract ausschuss data *
**************************



preserve
keep personal_id id0 name fname dateofbirth sex MP* ausschuss10_1  - bis16_23_b ausschuss17_1 - bis17_21_d
drop ausschuss14_31-bis14_42_a  // get rid of Sonderausschüsse
*drop position17_*_d //no entries

// keep personal_id  name fname dateofbirth sex MP* nam - bis14_42_a
// drop ausschuss1_1-bis9_20_b ausschuss12_1-bis13_22_c
// keep personal_id id0 name fname dateofbirth sex_x ausschuss10_1 - bis14_42_a
*reduce ausschuss data to  five LP's: 10, 11, 14, 16, 17


// Muss das bis 42 gehen? Die neue Version hat vermutlich weniger Ausschüsse, wohl 23. Ändern wenn LP17 eingefügt ist.

capture log close
log using "vars.log", replace
forvalues i = 1(1)23 {
display "ausschuss@_`i' maxpos@_`i' position@_`i'_a seit@_`i'_a bis@_`i'_a position@_`i'_b seit@_`i'_b bis@_`i'_b position@_`i'_c seit@_`i'_c bis@_`i'_c"
}
log close


*prepare for reshape
#delimit ;
local myx "
ausschuss@_1 maxpos@_1 position@_1_a seit@_1_a bis@_1_a position@_1_b seit@_1_b bis@_1_b position@_1_c seit@_1_c bis@_1_c
ausschuss@_2 maxpos@_2 position@_2_a seit@_2_a bis@_2_a position@_2_b seit@_2_b bis@_2_b position@_2_c seit@_2_c bis@_2_c
ausschuss@_3 maxpos@_3 position@_3_a seit@_3_a bis@_3_a position@_3_b seit@_3_b bis@_3_b position@_3_c seit@_3_c bis@_3_c
ausschuss@_4 maxpos@_4 position@_4_a seit@_4_a bis@_4_a position@_4_b seit@_4_b bis@_4_b position@_4_c seit@_4_c bis@_4_c
ausschuss@_5 maxpos@_5 position@_5_a seit@_5_a bis@_5_a position@_5_b seit@_5_b bis@_5_b position@_5_c seit@_5_c bis@_5_c
ausschuss@_6 maxpos@_6 position@_6_a seit@_6_a bis@_6_a position@_6_b seit@_6_b bis@_6_b position@_6_c seit@_6_c bis@_6_c
ausschuss@_7 maxpos@_7 position@_7_a seit@_7_a bis@_7_a position@_7_b seit@_7_b bis@_7_b position@_7_c seit@_7_c bis@_7_c
ausschuss@_8 maxpos@_8 position@_8_a seit@_8_a bis@_8_a position@_8_b seit@_8_b bis@_8_b position@_8_c seit@_8_c bis@_8_c
ausschuss@_9 maxpos@_9 position@_9_a seit@_9_a bis@_9_a position@_9_b seit@_9_b bis@_9_b position@_9_c seit@_9_c bis@_9_c
ausschuss@_10 maxpos@_10 position@_10_a seit@_10_a bis@_10_a position@_10_b seit@_10_b bis@_10_b position@_10_c seit@_10_c bis@_10_c
ausschuss@_11 maxpos@_11 position@_11_a seit@_11_a bis@_11_a position@_11_b seit@_11_b bis@_11_b position@_11_c seit@_11_c bis@_11_c
position@_11_d seit@_11_d bis@_11_d
ausschuss@_12 maxpos@_12 position@_12_a seit@_12_a bis@_12_a position@_12_b seit@_12_b bis@_12_b position@_12_c seit@_12_c bis@_12_c
ausschuss@_13 maxpos@_13 position@_13_a seit@_13_a bis@_13_a position@_13_b seit@_13_b bis@_13_b position@_13_c seit@_13_c bis@_13_c
ausschuss@_14 maxpos@_14 position@_14_a seit@_14_a bis@_14_a position@_14_b seit@_14_b bis@_14_b position@_14_c seit@_14_c bis@_14_c
ausschuss@_15 maxpos@_15 position@_15_a seit@_15_a bis@_15_a position@_15_b seit@_15_b bis@_15_b position@_15_c seit@_15_c bis@_15_c
ausschuss@_16 maxpos@_16 position@_16_a seit@_16_a bis@_16_a position@_16_b seit@_16_b bis@_16_b position@_16_c seit@_16_c bis@_16_c
ausschuss@_17 maxpos@_17 position@_17_a seit@_17_a bis@_17_a position@_17_b seit@_17_b bis@_17_b position@_17_c seit@_17_c bis@_17_c
ausschuss@_18 maxpos@_18 position@_18_a seit@_18_a bis@_18_a position@_18_b seit@_18_b bis@_18_b position@_18_c seit@_18_c bis@_18_c
position@_18_d  seit@_18_d bis@_18_d 
ausschuss@_19 maxpos@_19 position@_19_a seit@_19_a bis@_19_a position@_19_b seit@_19_b bis@_19_b position@_19_c seit@_19_c bis@_19_c
ausschuss@_20 maxpos@_20 position@_20_a seit@_20_a bis@_20_a position@_20_b seit@_20_b bis@_20_b position@_20_c seit@_20_c bis@_20_c
ausschuss@_21 maxpos@_21 position@_21_a seit@_21_a bis@_21_a position@_21_b seit@_21_b bis@_21_b position@_21_c seit@_21_c bis@_21_c
position@_21_d seit@_21_d bis@_21_d
ausschuss@_22 maxpos@_22 position@_22_a seit@_22_a bis@_22_a position@_22_b seit@_22_b bis@_22_b position@_22_c seit@_22_c bis@_22_c
ausschuss@_23 maxpos@_23 position@_23_a seit@_23_a bis@_23_a position@_23_b seit@_23_b bis@_23_b position@_23_c seit@_23_c bis@_23_c"
;
#delimit cr

// ausschuss@_25 maxpos@_25 position@_25_a seit@_25_a bis@_25_a position@_25_b seit@_25_b bis@_25_b position@_25_c seit@_25_c bis@_25_c
// ausschuss@_26 maxpos@_26 position@_26_a seit@_26_a bis@_26_a position@_26_b seit@_26_b bis@_26_b position@_26_c seit@_26_c bis@_26_c
// ausschuss@_27 maxpos@_27 position@_27_a seit@_27_a bis@_27_a position@_27_b seit@_27_b bis@_27_b position@_27_c seit@_27_c bis@_27_c
// ausschuss@_28 maxpos@_28 position@_28_a seit@_28_a bis@_28_a position@_28_b seit@_28_b bis@_28_b position@_28_c seit@_28_c bis@_28_c
// ausschuss@_29 maxpos@_29 position@_29_a seit@_29_a bis@_29_a position@_29_b seit@_29_b bis@_29_b position@_29_c seit@_29_c bis@_29_c
// ausschuss@_30 maxpos@_30 position@_30_a seit@_30_a bis@_30_a position@_30_b seit@_30_b bis@_30_b position@_30_c seit@_30_c bis@_30_c
// ausschuss@_31 maxpos@_31 position@_31_a seit@_31_a bis@_31_a position@_31_b seit@_31_b bis@_31_b position@_31_c seit@_31_c bis@_31_c
// ausschuss@_32 maxpos@_32 position@_32_a seit@_32_a bis@_32_a position@_32_b seit@_32_b bis@_32_b position@_32_c seit@_32_c bis@_32_c
// ausschuss@_33 maxpos@_33 position@_33_a seit@_33_a bis@_33_a position@_33_b seit@_33_b bis@_33_b position@_33_c seit@_33_c bis@_33_c
// ausschuss@_34 maxpos@_34 position@_34_a seit@_34_a bis@_34_a position@_34_b seit@_34_b bis@_34_b position@_34_c seit@_34_c bis@_34_c
// ausschuss@_35 maxpos@_35 position@_35_a seit@_35_a bis@_35_a position@_35_b seit@_35_b bis@_35_b position@_35_c seit@_35_c bis@_35_c
// ausschuss@_36 maxpos@_36 position@_36_a seit@_36_a bis@_36_a position@_36_b seit@_36_b bis@_36_b position@_36_c seit@_36_c bis@_36_c
// ausschuss@_37 maxpos@_37 position@_37_a seit@_37_a bis@_37_a position@_37_b seit@_37_b bis@_37_b position@_37_c seit@_37_c bis@_37_c
// ausschuss@_38 maxpos@_38 position@_38_a seit@_38_a bis@_38_a position@_38_b seit@_38_b bis@_38_b position@_38_c seit@_38_c bis@_38_c
// ausschuss@_39 maxpos@_39 position@_39_a seit@_39_a bis@_39_a position@_39_b seit@_39_b bis@_39_b position@_39_c seit@_39_c bis@_39_c
// ausschuss@_40 maxpos@_40 position@_40_a seit@_40_a bis@_40_a position@_40_b seit@_40_b bis@_40_b position@_40_c seit@_40_c bis@_40_c
// ausschuss@_41 maxpos@_41 position@_41_a seit@_41_a bis@_41_a position@_41_b seit@_41_b bis@_41_b position@_41_c seit@_41_c bis@_41_c
// ausschuss@_42 maxpos@_42 position@_42_a seit@_42_a bis@_42_a position@_42_b seit@_42_b bis@_42_b position@_42_c seit@_42_c bis@_42_c
// ausschuss@_24 maxpos@_24 position@_24_a seit@_24_a bis@_24_a position@_24_b seit@_24_b bis@_24_b position@_24_c seit@_24_c bis@_24_c


reshape long `myx', i(personal_id) j(lp 10 11 14 16 17) 
label variable lp "Legislaturperiode"




forvalues i = 1(1)23 {
destring ausschuss_`i', replace 
destring maxpos_`i', replace
destring position_`i'_a , replace 

// 	bm	1	Beratendes Mitglied
// 	om	2	Ordentliches Mitglied
// 	sm	3	Stellvertretendes Mitglied
// sv,sve	4	Stellvertretende(r) Vorsitzende(r)
// vo,ve	5	Vorsitzende(r) 

capture tostring seit_`i'_a , replace
gen dseit_`i'_a = date(seit_`i'_a, "MDY")
format dseit_`i'_a %td
capture tostring bis_`i'_a , replace
gen dbis_`i'_a = date(bis_`i'_a, "MDY")
format dbis_`i'_a %td

destring position_`i'_b , replace 
capture tostring seit_`i'_b , replace
gen dseit_`i'_b = date(seit_`i'_b, "MDY")
format dseit_`i'_b %td
capture tostring bis_`i'_b , replace
gen dbis_`i'_b = date(bis_`i'_b, "MDY")
format dbis_`i'_b %td

destring position_`i'_c , replace
capture tostring seit_`i'_c , replace
gen dseit_`i'_c = date(seit_`i'_c, "MDY")
format dseit_`i'_c %td
capture tostring bis_`i'_c , replace
gen dbis_`i'_c = date(bis_`i'_c, "MDY")
format dbis_`i'_c %td

capture destring position_`i'_d , replace
capture tostring seit_`i'_d , replace
capture gen dseit_`i'_d = date(seit_`i'_d, "MDY")
capture format dseit_`i'_d %td
capture tostring bis_`i'_d , replace
capture gen dbis_`i'_d = date(bis_`i'_d, "MDY")
capture format dbis_`i'_d %td


egen maxbis`i' = rowmax(dbis_`i'_a dbis_`i'_b dbis_`i'_c)
format maxbis`i' %td
egen minseit`i' = rowmin(dseit_`i'_a dseit_`i'_b dseit_`i'_c)
format minseit`i' %td
gen dauer`i' =  maxbis`i' - minseit`i'

// correct data problems
replace ausschuss_`i'=. if dauer`i'<0
replace ausschuss_`i'=. if dauer`i'>1455

// select DV: nur MdB's die jemals mindestens (eine Zeit lang) ordentliches Mitglied im Ausschuss waren ...
* Recode substitute members to low value
recode position_`i'_a 3=0
recode position_`i'_b 3=0
recode position_`i'_c 3=0
capture recode position_`i'_d 3=0

// 	bm	1	Beratendes Mitglied
// 	om	2	Ordentliches Mitglied
// 	sm	0	Stellvertretendes Mitglied !!!!!!!!!!!!!!!!
// sv,sve	4	Stellvertretende(r) Vorsitzende(r)
// vo,ve	5	Vorsitzende(r) 


egen maxxposition_`i' = rowmax(position_`i'_a position_`i'_b position_`i'_c)
capture replace maxxposition_`i' = position_`i'_d if position_`i'_d>maxxposition_`i'
*replace ausschuss_`i'=. if dauer`i'<0

*replace ausschuss_`i'=. if maxxposition_`i'<=1 & maxxposition_`i'!=.

}




* Es gibt negative values. Das darf nicht sein. Ebenso Werte grösser als 1455
*sum dauer* 

/*
list lp seit_2_* position_2_* bis_2_* if dauer2<0
list lp seit_10_* position_10_* bis_10_* if dauer10<0
list lp seit_12_* position_12_* bis_12_* if dauer12<0
list lp seit_13_* position_13_* bis_13_* if dauer13<0
list lp seit_18_* position_18_* bis_18_* if dauer18<0
list lp seit_19_* position_19_* bis_19_* if dauer19<0
list lp seit_22_* position_22_* bis_22_* if dauer22<0

list lp seit_6_* position_6_* bis_6_* if dauer2>1455
list lp seit_10_* position_10_* bis_10_* if dauer10>1455
list lp seit_12_* position_12_* bis_12_* if dauer12>1455

list lp minseit6 maxbis6 if dauer6>1455 & minseit6!=.
list lp minseit10 maxbis10 if dauer10>1455
list lp minseit12 maxbis12 if dauer12>1455 
*/

gen wahljahr= lp 
recode wahljahr 10=1983 11=1987 14=1998 16=2005 17=2009

*drop seit* bis* 



                                                                                                														
* id's for merge                                             
gen perso = 10000*personal_id + wahljahr
gen persid = 100000*lp + personal_id

sort perso
compress
save ausschuss.dta, replace

* for reshape at ausschus-level
*keep persid personal_id lp ausschuss* seit* bis* dseit* dbis* position* wahljahr

#delimit ;
local myx "
ausschuss_ 
position_@_a dseit_@_a dbis_@_a seit_@_a bis_@_a 
position_@_b dseit_@_b dbis_@_b seit_@_b bis_@_b
position_@_c dseit_@_c dbis_@_c seit_@_c bis_@_c
position_@_d dseit_@_d dbis_@_d seit_@_d bis_@_d"
;
#delimit cr


reshape long `myx', i(persid) j(com) 
label variable com "No of Comittee"
ren ausschuss_ ausschuss
drop if ausschuss!=1
drop ausschuss

lab define position__a 1 "Beratendes Mitgl." 0 "Stellv. Mitglied" 2 "Ord. Mitglied" 4 "Stellv. Vorsitz" 5 "Vorsitz"
label value position__a position__a
label variable position__a "Position in Comittee"

lab define position__b 1 "Beratendes Mitgl." 0 "Stellv. Mitglied" 2 "Ord. Mitglied" 4 "Stellv. Vorsitz" 5 "Vorsitz"
label value position__b position__b
label variable position__b "Position in Comittee"

lab define position__c 1 "Beratendes Mitgl." 0 "Stellv. Mitglied" 2 "Ord. Mitglied" 4 "Stellv. Vorsitz" 5 "Vorsitz"
label value position__c position__c
label variable position__c "Position in Comittee"

lab define position__d 1 "Beratendes Mitgl." 0 "Stellv. Mitglied" 2 "Ord. Mitglied" 4 "Stellv. Vorsitz" 5 "Vorsitz"
label value position__d position__d
label variable position__d "Position in Comittee"


*correct errornous date
replace dseit__a = date("29mar1983","DMY") if dseit__a ==date("1jan1983","DMY") 

bysort lp com: egen minseit = min(dseit__a)
format minseit %td

sort lp com dseit__a
order minseit

* initial assignment
*gen initial = (minseit == dseit__a)

*Using constituierede Sitzung
gen constituts = "."
replace constituts = "29.3.1983" if wahljahr==1983
replace constituts = "18.2.1987" if wahljahr==1987
replace constituts = "26.10.1998" if wahljahr==1998
replace constituts = "18.10.2005" if wahljahr==2005
replace constituts = "27.10.2009" if wahljahr==2009

gen constitut = date(constituts, "DMY")
format constitut %td


* we take two months
gen initial = (dseit__a - constitut  <=60)


* special rule for lp==17 because ther seem to be only a few initial assignments  - take a range of 14 days
*gen test = (dseit__a - minseit + 1 <=14)
*tab test lp  // shows that we get a reasonable distribution
*replace initial = 1 if  dseit__a - minseit + 1 <=14 

* initial position at least regular member
gen initialp = position__a
recode initialp 0/1=0 2/5=1 

ren com ausschuss

*gen test1 = (dseit__a - minseit  <=30)


***************
* Code the DV *
***************

/*

Create variable for descriptive report in table 2 in the paper

−	Agriculture
−	Transportation and Housing
−	Tourism
−	Budget
−	Foreign Affairs
−	Interior
−	Defense
−	Finance
−	Legal Affairs
−	Labor & Social Affairs
−	Economics
−	Family Affairs /Youth / Women /Health
−	Education, Research & Technology
−	Sports
−	EU
−	German Relations/Unification
−	Electoral Integrity
−	Petition
*/

gen comtab2 = .
* district com
replace comtab2 =1  if ausschuss==10 					   // Agriculture	
replace comtab2 =2  if ausschuss==14  & wahljahr<=1987	   // Transportation
replace comtab2 =2  if ausschuss==15  & wahljahr>=1998
replace comtab2 =2  if ausschuss==16  & wahljahr<=1987

replace comtab2 =3  if ausschuss==21  & wahljahr==1998	   // Tourism
replace comtab2 =3  if ausschuss==21  & wahljahr==2005
replace comtab2 =3  if ausschuss==20  & wahljahr==2009

* party com
replace comtab2 =4  if ausschuss==8  					    // Budget
replace comtab2 =5  if ausschuss==3                         // Foreign Affairs
replace comtab2 =6  if ausschuss==4                         // Interior
replace comtab2 =7  if ausschuss==12 					    // Defense
replace comtab2 =8  if ausschuss==7                         // Finance
replace comtab2 =9  if ausschuss==6                         // Legal Affairs
replace comtab2 =10 if ausschuss==11 					    // Labor & Social Affairs
replace comtab2 =11 if ausschuss==9                         // Economics

replace comtab2 =12 if ausschuss==13 & wahljahr>=1998		// Family affairs
replace comtab2 =12 if ausschuss==14 & wahljahr>=1998      
replace comtab2 =12 if ausschuss==13 & wahljahr<=1987     
                                                         
replace comtab2 =13 if ausschuss==18 & wahljahr<=1987       // Education, Research & Technology 
replace comtab2 =13 if ausschuss==19 & wahljahr<=1987        
replace comtab2 =13 if ausschuss==19 & wahljahr==1998
replace comtab2 =13 if ausschuss==19 & wahljahr==2005     
replace comtab2 =13 if ausschuss==18 & wahljahr==2009 

replace comtab2 =14 if ausschuss==21 & wahljahr<=1987	    // Environment
replace comtab2 =14 if ausschuss==16 & wahljahr>=1998     
                                                        
replace comtab2 =15 if ausschuss==20 & wahljahr<=2005       // Economic Development
replace comtab2 =15 if ausschuss==19 & wahljahr==2009                             

replace comtab2 =16 if ausschuss==16 & wahljahr==1998     // Human Rights
replace comtab2 =16 if ausschuss==18 & wahljahr==2005
replace comtab2 =16 if ausschuss==17 & wahljahr==2009
                              
replace comtab2 =17 if ausschuss==15 & wahljahr<=1987     // Media & telecommunications
replace comtab2 =17 if ausschuss==23 & wahljahr==1998		
replace comtab2 =17 if ausschuss==23 & wahljahr==2005
replace comtab2 =17 if ausschuss==22 & wahljahr==2009

replace comtab2 =18 if ausschuss==22 & wahljahr==1998        // EU
replace comtab2 =18 if ausschuss==22 & wahljahr==2005     
replace comtab2 =18 if ausschuss==21 & wahljahr==2009          

replace comtab2 =19 if ausschuss==5                          // Sport	                         
replace comtab2 =20 if ausschuss==17				       	 // German Unification
                           
*procedural com	                
replace comtab2 =21 if ausschuss==1 					     // Electoral Integrity
replace comtab2 =22 if ausschuss==2 				    	 // Petitions


#delimit ;
lab define comtab2
1  "Agriculture" 
2  "Transportation and Housing" 
3  "Tourism" 
4  "Budget" 
5  "Foreign Affairs"
6  "Interior"
7  "Defense"
8  "Finance"
9  "Legal Affairs"
10	"Labor & Social Affairs"
11	"Economics"
12	"Family Affairs /Youth / Women /Health"
13	"Education, Research & Technology"
14  "Environment"
15 	"Economic Development"
16	"Human Rights"
17  "Media & telecommunications"
18	"EU"
19  "Sports"
20	"German Relations/Unification"
21	"Electoral Integrity"
22	"Petition"
;
#delimit cr

label value comtab2 comtab2
label variable comtab2 "Comittee membership"

* Use estpost to generate table automatically 
* estpost tab rep78 foreign


* *district committee
gen porcom = .
replace porcom =1  if ausschuss==10 					   // 1 Agriculture	
replace porcom =1  if ausschuss==14  & wahljahr<=1987	   // 2 Transportation
replace porcom =1  if ausschuss==15  & wahljahr>=1998
replace porcom =1  if ausschuss==16  & wahljahr<=1987

replace porcom =1  if ausschuss==21  & wahljahr==1998	   // 3 Tourism
replace porcom =1  if ausschuss==21  & wahljahr==2005
replace porcom =1  if ausschuss==20  & wahljahr==2009

** party committee
gen polcom = .
replace polcom = 1  if ausschuss==8  					// 4 Budget
replace polcom = 1  if ausschuss==3                     // 5 Foreign Affairs
replace polcom = 1  if ausschuss==4                     // 6 Interior
replace polcom = 1  if ausschuss==12 					// 7 Defense
replace polcom = 1  if ausschuss==7                     // 8 Finance
replace polcom = 1  if ausschuss==6                     // 9 Legal Affairs
replace polcom = 1  if ausschuss==11 					// 10 Labor & Social Affairs
replace polcom = 1  if ausschuss==9                     // 11 Economics

                                                           
replace polcom = 1 if ausschuss==13 & wahljahr>=1998	// 12 Family affairs
replace polcom = 1 if ausschuss==14 & wahljahr>=1998     
replace polcom = 1 if ausschuss==13 & wahljahr<=1987    
                                                           
replace polcom = 1 if ausschuss==18 & wahljahr<=1987    // 13 Education, Research & Technology 
replace polcom = 1 if ausschuss==19 & wahljahr<=1987       
replace polcom = 1 if ausschuss==19 & wahljahr==1998
replace polcom = 1 if ausschuss==19 & wahljahr==2005    
replace polcom = 1 if ausschuss==18 & wahljahr==2009    

replace polcom = 1 if ausschuss==21 & wahljahr<=1987	// 14 Environment
replace polcom = 1 if ausschuss==16 & wahljahr>=1998    
                                                        
replace polcom = 1 if ausschuss==20 & wahljahr<=2005    // 15 Economic Development
replace polcom = 1 if ausschuss==19 & wahljahr==2009                                                          
															
replace polcom = 1 if ausschuss==16 & wahljahr==1998    // 16 Human Rights
replace polcom = 1 if ausschuss==18 & wahljahr==2005
replace polcom = 1 if ausschuss==17 & wahljahr==2009
                               
replace polcom = 1 if ausschuss==15 & wahljahr<=1987    // 17 Media & telecommunications
replace polcom = 1 if ausschuss==23 & wahljahr==1998		
replace polcom = 1 if ausschuss==23 & wahljahr==2005
replace polcom = 1 if ausschuss==22 & wahljahr==2009
                               
replace polcom = 1 if ausschuss==22 & wahljahr==1998    // 18 EU
replace polcom = 1 if ausschuss==22 & wahljahr==2005    
replace polcom = 1 if ausschuss==21 & wahljahr==2009            

replace polcom = 1 if ausschuss==5                      // 19 Sport
replace polcom = 1 if ausschuss==17						// 20 German Unification
   

** procedural committee
gen othcom = .
replace othcom =1 if ausschuss==1 					     // 21 Electoral Integrity
replace othcom =1 if ausschuss==2 				    	 // 22 Petitions


*Check coding:
fre comtab2
tab porcom comtab2
tab polcom comtab2
tab othcom comtab2


compress
save ausschuss_reshape.dta, replace
restore





* ausschuss data
drop ausschuss10_1  - bis16_23_b ausschuss17_1 - bis17_21_d



***********************************
* generate election-specific data *
***********************************

drop nameadd-l17_bornforeign occupation_80-occupation_key_09 l17_place_career1-l17_place_career2
drop l10_Other_political_position1-l17_Other_political_position2
*drop Volkskammer_87
drop *80 *90 *94 *02
drop not_attached*


*keep id0 name fname dateofbirth sex_x MP83-MP09 l10_terms_MdB-bundeslandlandesliste_09 district_name_wkr_83 l17_Other_political_position2 idnew

rename l10_terms_MdB terms_MdB_83
rename l11_terms_MdB terms_MdB_87
rename l14_terms_MdB terms_MdB_98
rename l16_terms_MdB terms_MdB_05
rename l17_terms_MdB terms_MdB_09

rename l10_mayor mayor_83
rename l11_mayor mayor_87
rename l14_mayor mayor_98
rename l16_mayor mayor_05
rename l17_mayor mayor_09

rename l10_city_council_member city_council_83
rename l11_city_council_member city_council_87
rename l14_city_council_member city_council_98
rename l16_city_council_member city_council_05
rename l17_city_council_member city_council_09

rename l10_secretary_federal_state secretary_federal_83
rename l11_secretary_federal_state secretary_federal_87
rename l14_secretary_federal_state secretary_federal_98
rename l16_secretary_federal_state secretary_federal_05
rename l17_secretary_federal_state secretary_federal_09

rename l10_secretary_state secretary_state_83
rename l11_secretary_state secretary_state_87
rename l14_secretary_state secretary_state_98
rename l16_secretary_state secretary_state_05
rename l17_secretary_state secretary_state_09

rename l10_state_legislator state_legislator_83
rename l11_state_legislator state_legislator_87
rename l14_state_legislator state_legislator_98
rename l16_state_legislator state_legislator_05
rename l17_state_legislator state_legislator_09

rename l10_state_governor state_governor_83
rename l11_state_governor state_governor_87
rename l14_state_governor state_governor_98
rename l16_state_governor state_governor_05
rename l17_state_governor state_governor_09

rename leader_experience_party_10 leader_experience_party_83
rename leader_experience_party_11 leader_experience_party_87
rename leader_experience_party_14 leader_experience_party_98
rename leader_experience_party_16 leader_experience_party_05
rename leader_experience_party_17 leader_experience_party_09

rename MP83 MP_83
rename MP87 MP_87
rename MP98 MP_98
rename MP05 MP_05
rename MP09 MP_09

rename dis_win83 dis_win_83
rename dis_win87 dis_win_87
rename dis_win98 dis_win_98
rename dis_win05 dis_win_05
rename dis_win09 dis_win_09

rename list_win83 list_win_83
rename list_win87 list_win_87
rename list_win98 list_win_98
rename list_win05 list_win_05
rename list_win09 list_win_09

gen parlparty = party_09
replace parlparty = party_05 if parlparty=="."
replace parlparty = party_98 if parlparty=="."
replace parlparty = party_87 if parlparty=="."
replace parlparty = party_83 if parlparty=="."

replace parlparty = partei_09 if parlparty=="."
replace parlparty = partei_05 if parlparty=="."
replace parlparty = partei_98 if parlparty=="."
replace parlparty = partei_87 if parlparty=="."
*replace parlparty = partei_83 if parlparty=="." // n.a.

* individual research uncoverd this
list id0 name fname Volkskammer_87 berlin* if parlparty=="."

replace parlparty = "CDU" if id0==91
replace parlparty = "CDU" if id0==212  // muss Werner Lensing sein
replace parlparty = "b90" if id0==1058

*****************
* personal data *
*****************
preserve
keep personal_id id0 Col1-dateofbirth sex parlparty
sort personal_id
compress
save personal.dta, replace
restore



drop Col1 id 



* get rid of comments on terms* variables
gen test05 = regexs(0) if(regexm(terms_MdB_05, "[*]"))
gen test98 = regexs(0) if(regexm(terms_MdB_98, "[*]"))

replace terms_MdB_05 = test05 if test05=="*"
replace terms_MdB_98 = test98 if test98=="*"
drop test*


*** legterm.XlSX eingfügen, corrected 83er data
drop terms_MdB_83
sort id0
merge  1:1 id0 using Legterm, keepusing(terms_MdB_83) 
tab _merge
order terms*
drop _merge



tab dis_win_83 list_win_83
tab dis_win_87 list_win_87
tab dis_win_98 list_win_98
tab dis_win_05 list_win_05
tab dis_win_09 list_win_09




* reshape data


/*
* List all variables in alphabetical order
preserve
drop personal_id
ds, alpha varwidth(30)
local myx  `r(varlist)' 
restore
*/

#delimit ;
local myx "MP                      green1_wkr             
bundeslandlandesliste  green2_sta             partei
cdu1_sta               green2_wkr             party
cdu1_wkr                                       pds1_sta
cdu2_sta               invalid1_sta           pds1_wkr
cdu2_wkr               invalid1_wkr           pds2_sta
city_council            invalid2_sta           pds2_wkr
csu1_sta               invalid2_wkr           secretary_federal
csu1_wkr               list_position          secretary_state
csu2_sta               list_win                spd1_sta
csu2_wkr               local_dis_bplace       spd1_wkr
dis_win                 local_dis_career       spd2_sta
district               local_dis_high_edu     spd2_wkr
district_name_wkr      local_dis_occu         state
eligiable_sta          local_dis_prim_edu     state_governor
eligiable_wkr          local_dis_residence    state_legislator
enter                  local_sta_bplace       terms_MdB
enter_date             local_sta_career      valid1_sta
exit                   local_sta_high_edu    valid1_wkr
exit_date             local_sta_occu         valid2_sta
fdp1_sta               local_sta_prim_edu    valid2_wkr
fdp1_wkr               local_sta_residence    voters_sta
fdp2_sta               margin                 voters_wkr
fdp2_wkr               mayor                   berlin
green1_sta			 leader_experience_party"             
;
#delimit cr

reshape long `myx', i(personal_id) j(year _05 _09 _83 _87 _98) string

* Daniel meint, dass  state besser ist wie bundeslandlandesliste
compress



* renaming variables to be able to use previous code

gen election_year = .
replace election_year = 1983 if year == "_83"
replace election_year = 1987 if year == "_87"
replace election_year = 1998 if year == "_98"
replace election_year = 2005 if year == "_05"
replace election_year = 2009 if year == "_09" 




* place of schooling: either primary or high school
gen distbirth = (local_dis_bplace=="1")
gen distschool = (local_dis_prim_edu=="1" | local_dis_high_edu=="1") 
gen distresid = (local_dis_residence=="1")  
                        
gen statebirth = (local_sta_bplace=="1")    
gen stateschool = (local_sta_prim_edu=="1"| local_sta_high_edu=="1")     
gen stateresid = (local_sta_residence=="1")   


* pol experience
gen local_assembly = (city_council=="1")

destring mayor, replace
recode mayor .=0



***********************
** Elecetoral System **
***********************

* Mode of election

destring list_position, replace 
destring district, replace




gen electedonnominal = (dis_win =="1")
gen electedonlist = (list_win =="1")

bysort MP: tab electedonnominal electedonlist

tab electedonnominal electedonlist, mis
bysort election_year: tab  electedonlist electedonnominal

bysort election_year: tab  electedonlist electedonnominal if MP=="1", mis



gen nomlist = electedonnominal
replace nomlist = . if electedonnominal==0 & electedonlist==0 /* This line should not be needed */




lab define nomlist 1 nominal 0 list 
label value nomlist nomlist
label variable nomlist "mode of election (1 = nominal)"

* Berlin & former Volkskammer as well as Nachruecker are list MdBs

* Berlin MdBs
destring berlin, replace
replace  nomlist = 0 if berlin==1

* Volkskammer
* Get rid of Volkskammer MdBs 
gen volkskammer = (Volkskammer_87=="TRUE")
replace  nomlist = 0 if volkskammer==1
drop volkskammer Volkskammer_87

* MP#s rücken über liste nach.
destring enter, replace
label variable enter "Nachrücker"
replace  nomlist = 0 if enter==1

bysort election_year: tab nomlist


replace MP="1" if nomlist!=.
bysort election_year: tab  nomlist if MP=="1", mis
bysort election_year: list  name fname if nomlist==. & MP=="1"

*keep if MP=="1"
*drop MP



*replace party = partei if party=="."
egen party1 = group(party), lname(party)
fre party1

egen parlparty1 = group(parlparty), lname(parlparty)
list name fname  berlin* if parlparty=="rep" // Regula Bott  - Grüne
list name fname  berlin* if parlparty=="andererkwv" // CDU bzw. CSU
fre parlparty1

gen parlparty2 = parlparty1
*recode parlparty2 1=. 2/3=5 4=1 5=2 6=6 7=5 8=6 9=4 10=5 11=3 12=2 13/14=5 15=1 16=2 17/18=6 19=4 20=5 21=3
recode parlparty2 1=. 2/4=5 5=1 6=2 7=6 8=7 9=5 10=6 11=4 12=5 13=6 14=3 15=2 16/17=5 18=1 19=2 20/21=6 22=4 23=5 24=3

lab define parlparty2 1 CDU 2 CSU 3 SPD 4 FDP 5 B90 6 LIN 7 DSU
label value parlparty2 parlparty2
label variable parlparty2 "party"

tab parlparty2 parlparty1

* Small party
gen small = inlist(parlparty2, 4,5,6,7)




* destring margin and change "," into "." 
*destring margin, dpcomma replace

destring margin,  replace

*für Gewinner: relativer Stimmenanteil des Siegers -  relativer Stimmenanteil des ersten Verlierers. 
*fuer Verlierer: eigener relativer Stimmenanteil - relativer Stimmenanteil des Siegers
* validity check
replace margin=. if nomlist==1 & margin<0


list year name if nomlist==0 & margin>0 & margin!=.
recode nomlist 0=1 if margin>0  & margin!=.
recode nomlist 1=0 if margin<0
replace margin=. if nomlist==0 & margin>0 & margin!=.

bysort election year:  sum margin voters_wkr

* Sieger:     Sieger% - 1.Verlierer%  
* Verlierer:  Sieger% - Verlierer% 
gen margin3 = abs(margin)					// only positive values

gen margin4 = margin if nomlist==0			// only negative values
replace margin4 = -margin if nomlist==1		// only negative values

local vars "eligiable voters invalid1 invalid2 valid1 valid2 spd1 spd2 cdu1 cdu2 csu1 csu2 green1 green2 fdp1 fdp2 pds1 pds2"
foreach x of local vars {
destring `x'_wkr, replace 
}


gen wkvotes = .
replace wkvotes = cdu1_wkr if parlparty2==1
replace wkvotes = csu1_wkr if parlparty2==2
replace wkvotes = spd1_wkr if parlparty2==3
replace wkvotes = fdp1_wkr if parlparty2==4
replace wkvotes = green1_wkr if parlparty2==5
replace wkvotes = pds1_wkr if parlparty2==6
replace wkvotes = spd1_wkr if id0== 1347 & election_year==1998 // Lafontaine switched parties

egen wkmax = rmax(cdu1_wkr csu1_wkr spd1_wkr fdp1_wkr green1_wkr pds1_wkr)
gen wkdiff = wkmax - wkvotes
gen margin2 = wkdiff/valid1_wkr //difference between Winner and MP voteshare  

gen wkmax2 = 0
replace wkmax2 = cdu1_wkr if parlparty2==1   & nomlist==1
replace wkmax2 = csu1_wkr if parlparty2==2   & nomlist==1
replace wkmax2 = spd1_wkr if parlparty2==3   & nomlist==1
replace wkmax2 = fdp1_wkr if parlparty2==4   & nomlist==1
replace wkmax2 = green1_wkr if parlparty2==5 & nomlist==1
replace wkmax2 = pds1_wkr if parlparty2==6   & nomlist==1
replace wkmax2 = spd1_wkr if id0== 1347 & election_year==1998 // Lafontaine switched parties

sum wkmax* if wkmax2!=0




gen legterm = . 
replace legterm = 0  if terms_MdB=="0"
replace legterm = 1  if terms_MdB=="1"
replace legterm = 2  if terms_MdB=="2"
replace legterm = 3  if terms_MdB=="3"
replace legterm = 4  if terms_MdB=="4"
replace legterm = 5  if terms_MdB=="5"
replace legterm = 6  if terms_MdB=="6"
replace legterm = 7  if terms_MdB=="7"
replace legterm = 8  if terms_MdB=="8"
replace legterm = 9  if terms_MdB=="9"
replace legterm = 10 if terms_MdB=="10"
replace legterm = 11 if terms_MdB=="11"




************************
** Merge Ausschussdata **
*************************

/*
gen perso = 10000*personal_id + election_year
sort perso
merge perso using ausschuss.dta
tab _merge
keep if _merge==3
drop _merge
*/

gen lp =.
replace lp = 10 if year=="_83"
replace lp = 11 if year=="_87"
replace lp = 14 if year=="_98"
replace lp = 16 if year=="_05"
replace lp = 17 if year=="_09"


* Assuming MPs do not drop in and out: this is true for comparison of LP 10 & 11 as well as LP 16 & 17
* replace missing values with previous or following nonmissing values
sort personal_id lp
recode legterm 0=.     // Value of 0 does not make sense. Coding error?
gen legterm1 = legterm

order   personal_id  legterm1 lp legterm


bysort personal_id: replace legterm1 = legterm1[_n+1] - (lp[_n+1]-lp[_n]) if legterm1 >= . & (lp[_n+1]==11) // replace missings in LP10
bysort personal_id: replace legterm1 = legterm1[_n+1] - (lp[_n+1]-lp[_n]) if legterm1 >= . & (lp[_n+1]==17) // replace missings in LP16
bysort personal_id: replace legterm1 = legterm1[_n-1] + (lp[_n]-lp[_n-1]) if legterm1 >= . & (lp[_n-1]==10) // replace missings in LP11
bysort personal_id: replace legterm1 = legterm1[_n-1] + (lp[_n]-lp[_n-1]) if legterm1 >= . & (lp[_n-1]==16) // replace missings in LP17

gen persid = 100000*lp + personal_id
egen test = group(persid)   // test wether id is sufficient.... and it is!
drop test
compress
sort persid
save data83-09.dta, replace

use ausschuss_reshape, clear
sort persid						
// but persid does not uniquily identify every observation because MPs are member in several committees per lp
// that is expected.
merge m:1 persid using data83-09.dta
tab _merge
keep if _merge==3
drop _merge

* two committees are not classified in tersm of DV
*tab ausschuss lp if initial==1 & initialp==1 & comtab2==. & newdv==.

* Ausschuss 18 in LP 14 & Ausschuss 22 in LP 11
*list name ausschuss lp  if initial==1 & initialp==1 & comtab2==. & newdv==.

compress
save data83-09ext.dta, replace
exit

