
*     ***************************************************************** * 
*     ***************************************************************** * 
*       File-Name:      graph.do                                        * 
*       Date:           April 3, 2016                                   * 
*       Author:         Gschwend, Zittel                                * 
*       Purpose:      	Graphs results                                  * 
* 	    Input File:     data.dta                                        * 
*       Data Output:                                                    *              
*       Machine:        office computer                 				* 
*     ****************************************************************  * 
*     ****************************************************************  * 

set more off
use data, clear

logit porcassignment1 locpol locbio   margin3 nomlist small legterm woman , cluster(personal_id)
keep if e(sample)
sum
save analysis1, replace
drawnorm b1-b8, seed(1234) n(`r(N)') means(e(b)) cov(e(V)) clear
merge using analysis1       /* merge caeses and variables from logit model to the simulated estimates */
tab _merge /* works like a charm */
drop _merge

*************************************************************
** Generate average treatment effect for localpol. 
** All other observations are set to their observed values.
*************************************************************

* 1 locpol=0 *
#delimit ;
    gen x_1 =    b1*0
               + b2*locbio
               + b3*margin3
               + b4*nomlist   
               + b5*small
			   + b6*legterm
			   + b7*woman
			   + b8;        
                            


* 2 locpol=2 ;
  
    gen x_2 =    b1*2
               + b2*locbio
               + b3*margin3
               + b4*nomlist  
               + b5*small
		       + b6*legterm
			   + b7*woman
			   + b8; 
				 
#delimit cr 

gen prob2=exp(x_2)/(1+exp(x_2))	/* Predicted Probs Scenario 2 */ 
gen prob1=exp(x_1)/(1+exp(x_1))	/* Predicted Probs Scenario 1 */ 

* We are interested in a first-difference of those scenarios: *
    gen diff_lp = prob2-prob1  /*  different values for the differences */
    egen  fd_lp = mean(diff_lp)
    scalar diff_lp = fd_lp 
		
* lower & upper bound for first-difference	
	_pctile diff_lp, p(2.5,97.5) 
    scalar lo_lp = r(r1)
    scalar up_lp = r(r2) 
	
	

	
*************************************************************
** Generate average treatment effect for nomlist. 
** All other observations are set to their observed values.
*************************************************************

* 3 nomlist=0 *
#delimit ;
    gen x_3 =    b1*locpol
               + b2*locbio
               + b3*margin3
               + b4*0 
               + b5*small
		       + b6*legterm
			   + b7*woman 
			   + b8;        


* 4 nomlist=1 ;
  
    gen x_4 =    b1*locpol
               + b2*locbio
               + b3*margin3
               + b4*1 
               + b5*small
		       + b6*legterm
			   + b7*woman 
			   + b8;        
			   
				   				   
#delimit cr 

gen prob4=exp(x_4)/(1+exp(x_4))	/* Predicted Probs Scenario 4 */ 
gen prob3=exp(x_3)/(1+exp(x_3))	/* Predicted Probs Scenario 3 */ 

* We are interested in a first-difference of those scenarios: *
    gen diff_nl = prob4-prob3  /*  different values for the differences */
    egen  fd_nl = mean(diff_nl)
    scalar diff_nl = fd_nl
		
* lower & upper bound for first-difference	
	_pctile diff_nl, p(2.5,97.5) 
    scalar lo_nl = r(r1)
    scalar up_nl = r(r2) 
	
	

*************************************************************
** Generate average treatment effect for locbio. 
** All other observations are set to their observed values.
*************************************************************

* 5 locbio=0 *
#delimit ;
    gen x_5 =    b1*locpol
               + b2*0
               + b3*margin3
               + b4*nomlist   
               + b5*small
			   + b6*legterm
			   + b7*woman
			   + b8;        
                            


* 6 locbio=3 ;
  
    gen x_6 =    b1*locpol
               + b2*3
               + b3*margin3
               + b4*nomlist  
               + b5*small
		       + b6*legterm
			   + b7*woman
			   + b8; 
				 
#delimit cr 

gen prob6=exp(x_6)/(1+exp(x_6))	/* Predicted Probs Scenario 6 */ 
gen prob5=exp(x_5)/(1+exp(x_5))	/* Predicted Probs Scenario 5 */ 

* We are interested in a first-difference of those scenarios: *
    gen diff_lb = prob6-prob5  /*  different values for the differences */
    egen  fd_lb = mean(diff_lb)
    scalar diff_lb = fd_lb 
		
* lower & upper bound for first-difference	
	_pctile diff_lb, p(2.5,97.5) 
    scalar lo_lb = r(r1)
    scalar up_lb = r(r2) 
	



*************************************************************
** Generate average treatment effect for legterm. 
** All other observations are set to their observed values.
*************************************************************

* 7 legterm=1 *
#delimit ;
    gen x_7 =    b1*locpol
               + b2*locbio
               + b3*margin3
               + b4*nomlist   
               + b5*small
			   + b6*1
			   + b7*woman
			   + b8;        
                            


* 8 legterm=10 ;
  
    gen x_8 =    b1*locpol
               + b2*locbio
               + b3*margin3
               + b4*nomlist  
               + b5*small
		       + b6*10
			   + b7*woman
			   + b8; 
				 
#delimit cr 

gen prob8=exp(x_8)/(1+exp(x_8))	/* Predicted Probs Scenario 8 */ 
gen prob7=exp(x_7)/(1+exp(x_7))	/* Predicted Probs Scenario 7 */ 

* We are interested in a first-difference of those scenarios: *
    gen diff_le = prob8-prob7  /*  different values for the differences */
    egen  fd_le = mean(diff_le)
    scalar diff_le = fd_le 
		
* lower & upper bound for first-difference	
	_pctile diff_le, p(2.5,97.5) 
    scalar lo_le = r(r1)
    scalar up_le = r(r2) 
	

*************************************************************
** Generate average treatment effect for small. 
** All other observations are set to their observed values.
*************************************************************

* 9 small=0 *
#delimit ;
    gen x_9 =    b1*locpol
               + b2*locbio
               + b3*margin3
               + b4*nomlist   
               + b5*0
			   + b6*legterm
			   + b7*woman
			   + b8;        
                            


* 10 small=1 ;
  
    gen x_10 =    b1*locpol
               + b2*locbio
               + b3*margin3
               + b4*nomlist  
               + b5*1
		       + b6*legterm
			   + b7*woman
			   + b8; 
				 
#delimit cr 

gen prob10=exp(x_10)/(1+exp(x_10))	/* Predicted Probs Scenario 10 */ 
gen prob9=exp(x_9)/(1+exp(x_9))	/* Predicted Probs Scenario 9 */ 

* We are interested in a first-difference of those scenarios: *
    gen diff_sm = prob10-prob9  /*  different values for the differences */
    egen  fd_sm = mean(diff_sm)
    scalar diff_sm = fd_sm 
		
* lower & upper bound for first-difference	
	_pctile diff_sm, p(2.5,97.5) 
    scalar lo_sm = r(r1)
    scalar up_sm = r(r2) 
	

	

*************************************************************
** Generate average treatment effect for woman. 
** All other observations are set to their observed values.
*************************************************************

* 11 woman=0 *
#delimit ;
    gen x_11 =    b1*locpol
               + b2*locbio
               + b3*margin3
               + b4*nomlist   
               + b5*small
			   + b6*legterm
			   + b7*0
			   + b8;        
                            


* 12 woman=1 ;
  
    gen x_12 =    b1*locpol
               + b2*locbio
               + b3*margin3
               + b4*nomlist  
               + b5*small
		       + b6*legterm
			   + b7*1
			   + b8; 
				 
#delimit cr 

gen prob12=exp(x_12)/(1+exp(x_12))	/* Predicted Probs Scenario 12 */ 
gen prob11=exp(x_11)/(1+exp(x_11))	/* Predicted Probs Scenario 11 */ 

* We are interested in a first-difference of those scenarios: *
    gen diff_wo = prob12-prob11  /*  different values for the differences */
    egen  fd_wo = mean(diff_wo)
    scalar diff_wo = fd_wo 
		
* lower & upper bound for first-difference	
	_pctile diff_wo, p(2.5,97.5) 
    scalar lo_wo = r(r1)
    scalar up_wo = r(r2) 
	

*************************************************************
** Generate average treatment effect for margin. 
** All other observations are set to their observed values.
*************************************************************
sum margin3
scalar min=`r(min)'
scalar max=`r(max)'
* 13 margin3=min *
#delimit ;
    gen x_13 =    b1*locpol
               + b2*locbio
               + b3*min
               + b4*nomlist   
               + b5*small
			   + b6*legterm
			   + b7*woman
			   + b8;        
                            


* 14 margin3=max ;
  
    gen x_14 =    b1*locpol
               + b2*locbio
               + b3*max
               + b4*nomlist  
               + b5*small
		       + b6*legterm
			   + b7*woman
			   + b8; 
				 
#delimit cr 

gen prob14=exp(x_14)/(1+exp(x_14))	/* Predicted Probs Scenario 14 */ 
gen prob13=exp(x_13)/(1+exp(x_13))	/* Predicted Probs Scenario 11 */ 

* We are interested in a first-difference of those scenarios: *
    gen diff_ma = prob14-prob13  /*  different values for the differences */
    egen  fd_ma = mean(diff_ma)
    scalar diff_ma = fd_ma 
		
* lower & upper bound for first-difference	
	_pctile diff_ma, p(2.5,97.5) 
    scalar lo_ma = r(r1)
    scalar up_ma = r(r2) 
	


	
	
	

gen coef = .
replace coef = fd_lp in 1
replace coef = fd_lb in 2
replace coef = fd_nl in 3
replace coef = fd_le in 4
replace coef = fd_sm in 5
replace coef = fd_wo in 6
replace coef = fd_ma in 7

gen coef1 = round(coef,.01) // round on second decimale for marker label




format fd_lp %9.2g
format fd_lb %9.2g
format fd_nl %9.2g
format coef %9.2g


gen up = .
replace up = up_lp in 1
replace up = up_lb in 2
replace up = up_nl in 3
replace up = up_le in 4
replace up = up_sm in 5
replace up = up_wo in 6
replace up = up_ma in 7


gen lo = .
replace lo = lo_lp in 1
replace lo = lo_lb in 2
replace lo = lo_nl in 3
replace lo = lo_le in 4
replace lo = lo_sm in 5
replace lo = lo_wo in 6
replace lo = lo_ma in 7


list lo coef coef1 up if lo!=.

capture drop xaxis
gen xaxis = _n in 1/7
#delimit ;
twoway (scatter xaxis coef,  mcolor(black) mlabel(coef1) mlabcolor(black) mlabposition(12) mlabgap(*3) mlabsize(small) ) 
( rspike lo up xaxis,  lwidth(thin) lcolor(black) horizontal),
legend(off) ytitle(" ") xtitle("Effect on Pr(District Comittee Assignment)", color(black) alignment(bottom )) 
xscale(titlegap(3) nofextend)  
yscale(noline)  
ylabel(  .8 " "
			   1  "Local Politics"  
			   2  "Local Biography"
               3  "Mode of Election" 
			   4  "Legislative Terms"  
               5  "Small Party" 			   
               6  "Woman" 			   
               7  "Margin"  
			   7.2 " "
			   ,  angle(horizontal) labsize(small) noticks nogrid) 
xline(0, lp(shortdash)lwidth(vthin)lcolor(black)  )
xlabel(-.3(.1).3,  labsize(small) labcolor(black) )
graphregion(fcolor(white))
saving(ate, replace)
;
#delimit cr


graph export ate.tif, replace
graph export ate.pdf, replace
graph export ate.png, replace
graph export ate.eps, replace preview(on)




capture drop xaxis
gen xaxis = _n in 1/7
#delimit ;
twoway (scatter xaxis coef,  mcolor(black) msize(1)) 
( rspike lo up xaxis,  lwidth(thin) lcolor(black) horizontal),
legend(off) ytitle(" ") xtitle("Effect on Pr(District Comittee Assignment)", color(black) alignment(bottom )) 
xscale(titlegap(2) nofextend)  
yscale(noline)  
ylabel( .8 " "
			   1  "Local Politics"  
			   2  "Local Biography"
               3  "Mode of Election" 
			   4  "Legislative Terms"  
               5  "Small Party" 			   
               6  "Woman" 			   
               7  "Margin"  
			   7.2 " "
			   ,  angle(horizontal) labsize(small) noticks nogrid) 
xline(0, lp(shortdash)lwidth(vthin)lcolor(black)  )
xlabel(-.3(.1).3,  labsize(small) labcolor(black) )
graphregion(fcolor(white))
saving(ate1, replace)
;
#delimit cr


graph export ate1.tif, replace
graph export ate1.pdf, replace
graph export ate1.png, replace
graph export ate1.eps, replace preview(on)



exit


