
*     ***************************************************************** * 
*     ***************************************************************** * 
*       File-Name:      recode.do                                       * 
*       Date:           March 25, 2016                                  * 
*       Author:         Gschwend, Zittel                                * 
*       Purpose:      	Performs basic                                  *
*                       recoding of variables                           * 
* 	    Input File:     data83-09.dta                                   * 
*       Data Output:                                              *              
*     ****************************************************************  * 
*     ****************************************************************  * 

set more off
use data83-09ext.dta, clear
sum personal_id
assert r(N)== 6916  & r(min)==1 & r(max)==1904 & r(sum)==5847230


fre election_year 


bysort wahljahr: sum margin voters_wkr




****************
** Localness  **
****************

sum distbirth distschool distresid 
sum statebirth stateschool stateresid

* What about localness at least at the state level??

* Tabelle 1
tab distbirth election_year, col 
tab distschool election_year, col 
tab distresid election_year, col 

egen localbio = rsum(distbirth distschool distresid)
replace localbio = . if distbirth==. & distschool==. & distresid==.
fre localbio

gen localbio1 = distbirth + distschool + distresid
tab localb*, mis

* take maximum value per person across election years
bysort personal_id: egen locbio = max(localbio)



*alpha distbirth distschool distresid , item detail
*alpha distbirth distschool distresid statebirth stateschool stateresid, item detail


sum local_assembly mayor
tab local_assembly election_year, col 
tab mayor election_year, col 


egen localpol = rsum(local_assembly mayor)
replace localpol = . if local_assembly==. & mayor==.
gen localpol1 = local_assembly + mayor
tab localp*, mis

* take maximum value per person across election years
bysort personal_id: egen locpol = max(localpol)


*********************************
** Experience as local leader  **
*********************************
destring leader_experience_party, replace 
gen localexp = inlist(leader_experience_party, 31, 33, 35)

lab define localexp 1 "yes" 0 "no" 
label value localexp localexp
label variable localexp "Experience as local party leader (=1)"



***********************
** Elecetoral System **
***********************

* Mode of election

*Ist das realistisch?
tab nomlist election_year, col 


* Marginality (aus "rate" - candidate votes)
* Margin for winner has the same value as the first looser
sum margin electedonnominal 





***************************
** DV: Type of Committee **
***************************

/*

* at least one pork OR policy comittee OR other committee
gen porkcom1 = (porc>=1)
gen policycom1 = (polc>=1)
gen othcom1 = (othc>=1)

*/

fre polcom porcom othcom

*new dv 1= at least 1 porkcom, 2= no pork but at least one party, 0 = others
gen newdv = .
replace newdv = 0 if othcom==1
replace newdv = 2 if polcom==1
replace newdv = 1 if porcom==1
*
*replace newdv =. if othcom==. & newdv==0 /* MPs that neither party (policy) nor pork nor others */

lab define newdv 1 "pork committee" 0 "other committee" 2 "party committee" 
label value newdv newdv
label variable newdv "Type of Committee"

tab newdv, mis

*list name election_year if newdv==.

tab newdv

* There are not assigned commitees.
tab ausschuss lp if initial==1 & initialp==1 & comtab2==. & newdv==.
* Ausschuss 22 in LP 11
* Ausschuss 18 in LP 14 


***************************
* DV: Type of Committee Assignment: Variable for Binary Logistics
* A Binary Logistic Regression distinguishes between assignments to pork committees and all other assignments.
* We would expect that nomainally elected legislators, and local legislators are more likely to end up in pork committees
* I think this model makes more sense
***************************

gen porcassignment = .
replace porcassignment = 1 if newdv==1
replace porcassignment = 0 if newdv==2 | newdv==0
replace porcassignment =. if newdv==.

lab define porcassignment 1 "pork committee" 0 "other committee" 
label value porcassignment porcassignment
label variable porcassignment "porc committee (=1)"

tab porcassignment, mis

tab newdv porcassignment, mis





**********************
** Further Controls **
**********************

*legterm & legyear: legislative experinec in Bundestag

sum legterm 

tab legterm election_year, col 

* gender
gen woman = sex
recode woman 2=1 1=0
lab define woman 1 "woman" 0 "men" 
label value woman woman
label variable woman "woman (=1)"
tab woman




**********************
** Election dummies **
**********************
tab election_year

tabulate election_year, gen(y)




**************************************
** DV: at least in 1 pork committee **
**************************************

* porcassignment1 = 1 if MdB is in a given LP at least in one pork comittee, otherwise 0


keep if initial==1 & initialp==1 
drop if porcassignment==.


sort personal_id lp porcassignment
bysort personal_id lp: gen porcid = _n 							// count No of Com's per MdB*LP (given initial==1 & initialp==1)
bysort personal_id lp: gen porcassignment1 = porcassignment[_N] // If there is a Porc com, then 1 otherwise 0 ("Pork trumps everything else")
bysort personal_id lp: replace porcassignment1=. if _n<_N 		// Only one value per MdB and LP, set other com assignments to missing

tab porcassignment1
tab porcassignment porcassignment1, mis
* We loose 595 comittee assignments




*************
** Table 2 **
*************

* Create table of descriptives of DV: such as Table 2 
estpost tab comtab2   // legilslator  comm assignment with initial==1 & initialp==1
eststo est0

#delimit ;
esttab est0 using tab2.rtf, replace rtf cells("b(label(N)) pct(label(%) fmt(2))") 
varlabels(`e(labels)', blist(Total))
varwidth(50) alignment(r)
nonumber nomtitle noobs  
;
#delimit cr



compress
save data, replace
